cdist-type__ping(7)
==================================

NAME
----
cdist-type__ping - Try to connect to host and return 'pong' on success


DESCRIPTION
-----------
A simple type which tries to connect to a remote host and runs a simple command
to ensure everything is working.


REQUIRED PARAMETERS
-------------------
None.


OPTIONAL PARAMETERS
-------------------
None.


EXAMPLES
--------

.. code-block:: sh

    __ping


AUTHORS
-------
Olliver Schinagl <oliver--@--schinagl.nl>


COPYING
-------
Copyright \(C) 2018 Schinagl. You can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.
